@@ -4,6 +4,7 @@ from .core.core_api import create_model, create_model_version, delete_model, ini
 from .core.model_tags import add_model_tags, delete_model_tag, get_model_tags
 from .core.types.model import ModelColor, ModelIcon
 from .core.utils import generate_features_schema_from_shape
+from .inference.api.dataset import SparkSQLDataSource, BigQueryDataSource
 from .model import Model
 
 __all__ = [
@@ -21,4 +22,6 @@ __all__ = [
     "generate_features_schema_from_shape",
     # Inference
     "Model",
+    "SparkSQLDataSource",
+    "BigQueryDataSource"
 ]
