@@ -219,7 +219,6 @@ def create_model_version(
     multiclass_labels: Optional[List[str]] = None,
     feature_importance: Optional[Dict[str, float]] = None,
     mapping: Optional[Dict[str, str]] = None,
-    datasets: Optional[Dict[str, Any]] = None,
 ) -> Optional[Model]:
     """Creates a new model version, and defines a schema for it.
 
@@ -233,11 +232,10 @@ def create_model_version(
         raw_inputs: Schema for raw inputs (See notes).
         metrics: Schema for prediction metrics (See notes).
         model_data_type: Model data type.
-        labels: Labels of multi-label, multiclass or binary model. Takes precedence over "multiclass_labels".
+        labels: Labels of multi-label, multiclass or binary model. Deprecated.
         multiclass_labels: Labels of multi-label, multiclass or binary model. Same as "labels", Deprecated.
         feature_importance: Features' importance.
         mapping: General mapping (See notes).
-        datasets: Datasets configuration.
 
     Notes:
         * A schema is a dict, in which the keys are the fields you wish to report, and the
@@ -265,6 +263,7 @@ def create_model_version(
             | "datetime"    | datetime.datetime, or str representing a datetime in ISO-8601 format
             | "vector"      | list of floats
             | "text"        | str (to be used as free text)
+            | "dict"        | dict[str, int]
         * The supported data types are:
             * "tabular"
             * "nlp"
@@ -277,9 +276,12 @@ def create_model_version(
              }
           ```
         * The mapping allowed fields are:
-            * batch_id_column_name: The name of the key in the `raw_inputs` dict that holds the value of the `batch_id`.
-            * relevance_column_name: The name of the key in the `predictions` dict that holds the value of the `relevance` score of models of type `ranking`.
-            * actual_relevance_column_name: The name of the key in the `actuals` dict that holds the value of the `relevance` score of models of type `ranking`.
+            * batch_id_column_name: The name of the key in the `raw_inputs`
+            dict that holds the value of the `batch_id`.
+            * relevance_column_name: The name of the key in the `predictions`
+            dict that holds the value of the `relevance` score of models of type `ranking`.
+            * actual_relevance_column_name: The name of the key in the `actuals`
+            dict that holds the value of the `relevance` score of models of type `ranking`.
 
     Returns:
         Model object for the new version.
@@ -291,7 +293,14 @@ def create_model_version(
 
     if multiclass_labels is not None:
         warnings.warn(
-            '"multiclass_labels" parameter is deprecated, please use "labels".',
+            "The `multiclass_labels` parameter is deprecated, please use the `dict` field type.",
+            DeprecationWarning,
+            stacklevel=3,
+        )
+
+    if labels is not None:
+        warnings.warn(
+            "The `labels` parameter is deprecated, please use the `dict` field type.",
             DeprecationWarning,
             stacklevel=3,
         )
@@ -310,7 +319,6 @@ def create_model_version(
             labels=labels if labels is not None else multiclass_labels,
             feature_importance=feature_importance,
             mapping=mapping,
-            datasets=datasets,
         )
     )
 
