@@ -11,6 +11,7 @@ from aporia.core.base_model import BaseModel, validate_model_ready
 from aporia.core.errors import handle_error
 from aporia.core.logging_utils import LOGGER_NAME
 from aporia.core.types.field import FieldValue
+from aporia.inference.api.dataset import connect_dataset, DataSource
 from aporia.inference.api.log_model_properties import (
     log_index_to_word_mapping,
     set_feature_importance,
@@ -329,6 +330,126 @@ class InferenceModel(BaseModel):
                 )
             )
 
+    @validate_model_ready
+    def connect_serving(
+        self,
+        data_source: DataSource,
+        id_column: str,
+        timestamp_column: str,
+        predictions: Optional[Dict[str, str]] = None,
+        features: Optional[Dict[str, str]] = None,
+        labels: Optional[Dict[str, str]] = None,
+        raw_inputs: Optional[Dict[str, str]] = None,
+    ):
+        """Connect to external serving data set.
+
+        Args:
+            data_source: The data source to fetch the data set from.
+            id_column: The name of the id column.
+            timestamp_column: The name of the timestamp column.
+            features: Mapping from feature name to column name.
+            predictions: Mapping from prediction name to column name.
+            labels: Mapping from actual name to column name.
+            raw_inputs: Mapping from raw input name to column name.
+        """
+        with self.handle_error("Connection to serving failed, error: {}"):
+            self._event_loop.run_coroutine(
+                connect_dataset(
+                    http_client=self._http_client,
+                    model_id=self.model_id,
+                    model_version=self.model_version,
+                    environment=self._config.environment,
+                    dataset="serving",
+                    data_source=data_source,
+                    id_column=id_column,
+                    timestamp_column=timestamp_column,
+                    features=features,
+                    predictions=predictions,
+                    labels=labels,
+                    raw_inputs=raw_inputs,
+                )
+            )
+
+    @validate_model_ready
+    def connect_training(
+        self,
+        data_source: DataSource,
+        id_column: str,
+        timestamp_column: str,
+        predictions: Optional[Dict[str, str]] = None,
+        features: Optional[Dict[str, str]] = None,
+        labels: Optional[Dict[str, str]] = None,
+        raw_inputs: Optional[Dict[str, str]] = None,
+    ):
+        """Connect to external training data set.
+
+        Args:
+            data_source: The data source to fetch the data set from.
+            id_column: The name of the id column.
+            timestamp_column: The name of the timestamp column.
+            features: Mapping from feature name to column name.
+            predictions: Mapping from prediction name to column name.
+            labels: Mapping from prediction name to column name.
+            raw_inputs: Mapping from raw input name to column name.
+        """
+        with self.handle_error("Connection to training set failed, error: {}"):
+            self._event_loop.run_coroutine(
+                connect_dataset(
+                    http_client=self._http_client,
+                    model_id=self.model_id,
+                    model_version=self.model_version,
+                    environment=self._config.environment,
+                    dataset="training",
+                    data_source=data_source,
+                    id_column=id_column,
+                    timestamp_column=timestamp_column,
+                    features=features,
+                    predictions=predictions,
+                    labels=labels,
+                    raw_inputs=raw_inputs,
+                )
+            )
+
+    @validate_model_ready
+    def connect_testing(
+        self,
+        data_source: DataSource,
+        id_column: str,
+        timestamp_column: str,
+        predictions: Optional[Dict[str, str]] = None,
+        features: Optional[Dict[str, str]] = None,
+        labels: Optional[Dict[str, str]] = None,
+        raw_inputs: Optional[Dict[str, str]] = None,
+    ):
+        """Connect to external test data set.
+
+        Args:
+            data_source: The data source to fetch the data set from.
+            id_column: The name of the id column.
+            timestamp_column: The name of the timestamp column.
+            features: Mapping from feature name to column name.
+            predictions: Mapping from prediction name to column name.
+            labels: Mapping from prediction name to column name.
+            raw_inputs: Mapping from raw input name to column name.
+        """
+        with self.handle_error("Connection to test set failed, error: {}"):
+            self._event_loop.run_coroutine(
+                connect_dataset(
+                    http_client=self._http_client,
+                    model_id=self.model_id,
+                    model_version=self.model_version,
+                    environment=self._config.environment,
+                    dataset="testing",
+                    data_source=data_source,
+                    id_column=id_column,
+                    timestamp_column=timestamp_column,
+                    features=features,
+                    predictions=predictions,
+                    labels=labels,
+                    raw_inputs=raw_inputs,
+                )
+            )
+
     @validate_model_ready
     def flush(self, timeout: Optional[int] = None) -> Optional[int]:
         """Waits for all currently scheduled tasks to finish.
