@@ -26,6 +26,45 @@ STRING_UNIQUE_RATIO = 0.25
 MIN_UNIQUE_VALUES_FOR_TEXT = 50
 
 
+def _infer_string_data_for_text_or_string(data: pd.Series) -> FieldType:
+    """Convert a numpy/pandas of series contains only strings to a FieldType
+
+    Args:
+        data: Numpy data series
+
+    Returns:
+        FieldType that matches the dtype
+    """
+    # We need to decided if a string type is str or text
+    # We check if there are more than 50 unique values
+    # which are more than 25% of the total values
+    _, unique_counts = np.unique(data.values, return_counts=True)
+    uniques = len(unique_counts)
+    if uniques > MIN_UNIQUE_VALUES_FOR_TEXT and uniques > data.shape[0] * STRING_UNIQUE_RATIO:
+        return FieldType.TEXT
+
+    return FieldType.STRING
+
+
+def _infer_object_dtype_column(data: pd.Series) -> Optional[FieldType]:
+    """Attempts to convert a numpy/pandas series of object dtype to a FieldType
+
+    Args:
+        data: Numpy data series
+
+    Returns:
+        FieldType that matches the dtype, or None if conversion is impossible
+    """
+    if data.size == 0:
+        return None
+    elif data.apply(lambda x: isinstance(x, dict)).all():
+        return FieldType.DICT
+    elif data.apply(lambda x: isinstance(x, str)).all():
+        return _infer_string_data_for_text_or_string(data=data)
+
+    return None
+
+
 def infer_type_from_dtype_and_data(
     dtype: np.dtype, data: Optional[pd.Series]
 ) -> Optional[FieldType]:
@@ -46,6 +85,9 @@ def infer_type_from_dtype_and_data(
 
         return category_type
 
+    if dtype.kind == "O":
+        return _infer_object_dtype_column(data=data)
+
     if data is not None and not data.empty:
         if dtype.kind in NUMERIC_DTYPES and isinstance(data.values[0], abc.Iterable):
             return FieldType.VECTOR
@@ -54,13 +96,7 @@ def infer_type_from_dtype_and_data(
         # We check if there are more than 50 unique values
         # which are more than 25% of the total values
         if dtype.kind in STRING_DTYPES and len(data.shape) > 0:
-            _, unique_counts = np.unique(data.values, return_counts=True)
-            uniques = len(unique_counts)
-            if (
-                uniques > MIN_UNIQUE_VALUES_FOR_TEXT
-                and uniques > data.shape[0] * STRING_UNIQUE_RATIO
-            ):
-                return FieldType.TEXT
+            return _infer_string_data_for_text_or_string(data=data)
 
     return DTYPE_TO_FIELD_TYPE.get(dtype.kind)  # type: ignore
 
@@ -130,37 +166,30 @@ def infer_schema_from_dataframe(data: pd.DataFrame) -> Optional[Dict[str, str]]:
         * If data contains a column with a type that doesn't match any of the rules
           described above, an error will be raised.
     """
-    context = get_context()
-    try:
-        if not isinstance(data, pd.DataFrame):
-            raise AporiaError(
-                "cannot infer schema from {}, data must be a pandas DataFrame".format(type(data))
-            )
-
-        schema = OrderedDict()
-        for column_name, values in data.items():
-            values_without_nulls = values.dropna().infer_objects()
-            column_type = infer_type_from_dtype_and_data(
-                values_without_nulls.dtype, values_without_nulls
-            )
-            if column_type is None:
-                raise AporiaError(
-                    "the dtype {} of column {} is not supported".format(
-                        values_without_nulls.dtype, column_name
-                    )
-                )
-
-            schema[column_name] = column_type.value
-
-        return schema
-
-    except Exception as err:
-        handle_error(
-            message_format="Inferring schema from dataframe failed, {}",
-            verbose=context.config.verbose,
-            throw_errors=context.config.throw_errors,
-            debug=context.config.debug,
-            original_exception=err,
+    if not isinstance(data, pd.DataFrame):
+        raise AporiaError(
+            f"cannot infer schema from {type(data)}, data must be a pandas DataFrame"
         )
 
-    return None
+    schema = OrderedDict()
+    not_inferable_columns = []
+    for column_name, values in data.items():
+        column_name = str(column_name)
+
+        values_without_nulls = values.dropna().infer_objects()
+        column_type = infer_type_from_dtype_and_data(
+            values_without_nulls.dtype, values_without_nulls
+        )
+        if column_type is None:
+            not_inferable_columns.append(column_name)
+        else:
+            schema[column_name] = column_type.value
+
+    if len(not_inferable_columns) > 0:
+        raise AporiaError(
+            f"Could not infer the type of columns {not_inferable_columns}. "
+            "To fix, make sure to set column dtype. For example "
+            f"df['{not_inferable_columns[0]}'] = df['{not_inferable_columns[0]}'].astype(np.int32)"
+        )
+
+    return schema
