@@ -22,6 +22,8 @@ from .training_validator import TrainingDataset, TrainingValidator
 logger = logging.getLogger(LOGGER_NAME)
 
 
+# Since we're sending it all in one batch, too many datapoints might cause it to fail.
+MAX_LIMIT = 50000
 SAMPLE_SIZE = 1000
 
 
@@ -44,10 +46,13 @@ class TrainingModel(BaseModel):
         features: Union[DataFrame, ndarray],
         labels: DataFrame,
         raw_inputs: Optional[DataFrame] = None,
+        sample: bool = True,
     ):
         """See aporia.model.Model."""
         logger.debug("Logging training set.")
-        with self.handle_error("Logging training set failed, error: {}"):
+        with self.handle_error(
+            "Logging training set failed, error: {}"
+        ):
             version_schema = self.get_version_schema()
             validator = TrainingValidator(
                 dataset_type=TrainingDataset.TRAINING, schema=version_schema
@@ -68,7 +73,12 @@ class TrainingModel(BaseModel):
                     features=features
                 )
 
-            self.log_training_sample(features=features_dataframe, labels=labels)
+            self.log_training_data(
+                features=features_dataframe,
+                labels=labels,
+                raw_inputs=raw_inputs,
+                sample=sample,
+            )
             self.log_training_set_aggregations(
                 features=calculate_dataframe_training_data(features_dataframe, features_schema),
                 labels=calculate_dataframe_training_data(
@@ -174,28 +184,39 @@ class TrainingModel(BaseModel):
         )
 
     @validate_model_ready
-    def log_training_sample(
+    def log_training_data(
         self,
         features: Union[DataFrame, ndarray],
         labels: DataFrame,
+        raw_inputs: Optional[DataFrame] = None,
+        sample: Optional[bool] = True,
     ):
-        """Logs training sample.
+        """Logs training data.
 
         Args:
             features: Training set features
             labels: Training set labels
+            raw_inputs: Training set raw inputs
+            sample: Should we report all data or just a sample
 
         Notes:
             * As this is a sample for analytical purpose, we log a maximum of 1000 rows.
         """
+        report_size = SAMPLE_SIZE if sample else MAX_LIMIT
+
         if isinstance(features, ndarray):
             features, _ = self._build_features_dataframe_and_schema(features)
 
         # Null values are replaced with np.nan, because orjson can't serialize pd.NA
         features_sample = cast(
-            DataFrame, features.sample(min(SAMPLE_SIZE, len(features))).fillna(nan)
+            DataFrame, features.sample(min(report_size, len(features))).fillna(nan)
         )
-        labels_sample = cast(DataFrame, labels.sample(min(SAMPLE_SIZE, len(labels))).fillna(nan))
+        labels_sample = cast(DataFrame, labels.sample(min(report_size, len(labels))).fillna(nan))
+
+        if raw_inputs is not None:
+            raw_inputs_sample = cast(
+                DataFrame, raw_inputs.sample(min(report_size, len(raw_inputs))).fillna(nan)
+            )
 
         self._event_loop.run_coroutine(
             log_training_sample_data(
@@ -204,6 +225,7 @@ class TrainingModel(BaseModel):
                 model_version=self.model_version,
                 features=features_sample.to_dict("records"),
                 labels=labels_sample.to_dict("records"),
+                raw_inputs=raw_inputs_sample.to_dict("records") if raw_inputs is not None else None,
             )
         )
 
